# Benchmarks

Computational operations in anndata are consistently benchmarked [here](https://github.com/ivirshup/anndata-benchmarks).

Below follows a simple benchmark showing read-write efficiency.

```{toctree}
:maxdepth: 1

benchmark-read-write
```
